
.. image:: https://secure.travis-ci.org/FedericoCeratto/desktop-security-assistant.png?branch=master
   :target: http://travis-ci.org/FedericoCeratto/desktop-security-assistant
   :alt: Build status

.. image:: https://coveralls.io/repos/FedericoCeratto/desktop-security-assistant/badge.png?branch=master
   :target: https://coveralls.io/r/FedericoCeratto/desktop-security-assistant?branch=master
   :alt: Coverage

.. image:: https://pypip.in/download/desktop-security-assistant/badge.png
    :target: https://pypi.python.org/pypi//desktop-security-assistant/
    :alt: Downloads

.. image:: https://pypip.in/version/desktop-security-assistant/badge.png
    :target: https://pypi.python.org/pypi/desktop-security-assistant/
    :alt: Latest Version

.. image:: https://pypip.in/license/desktop-security-assistant/badge.png
    :target: https://pypi.python.org/pypi/desktop-security-assistant/
    :alt: License

Desktop security assistant
==========================

An easy to use tool for desktop users to improve the security of their system.

It scans your Linux desktop or laptop and provide a set of suggestions.


How is it different from security scanners like Tiger?
------------------------------------------------------

* Focused on desktop users rather than servers administrators
* Provides suggestions on every aspect of security: software and hardware configuration and usage
* Simple hints on level of risk and how difficult it is to mitigate

Development status
------------------

In development

Roadmap
-------

* Implement more checks
